/*
   Name:    "ShootOut-oo.rex"

   Invoke:  "java com.ibm.bsf.Main -lang rexx -in ShootOut-oo.rex"
                or
            "java com.ibm.bsf.Main            -in ShootOut-oo.rex"

   Purpose:  create a window with a choice-object and two text-fields and buttons;
             if the ok-button is pressed then popup another window and display what
             was chosen and entered.

   Needs:    IBM's "Bean Scripting Framework" (BSF)
             (cf. "http://oss.software.ibm.com/developerworks/projects/bsf")

             and the package "bsf4rexx"
             (cf. "http://nestroy.wi-inf.uni-essen.de/Forschung/rgf/Entwicklung.html")

   Date:    2001-04-21

   Author:   Rony G. Flatscher, WU Wien University,
*/

        /* import Java classes          */
.bsf~import("awtButton",        "java.awt.Button")
.bsf~import("awtFrame",         'java.awt.Frame')
.bsf~import("awtGBConstraints", 'java.awt.GridBagConstraints')
.bsf~import("awtGridBagLayout", 'java.awt.GridBagLayout')
.bsf~import("awtInsets",        'java.awt.Insets')
.bsf~import("awtLabel",         "java.awt.Label")
.bsf~import("awtTextArea",      "java.awt.TextArea")

        /* create labels                */
label1 = .awtLabel~new('String', 'Your question?')
label2 = .awtLabel~new('St'    , 'Well, consider this answer:' )

        /* get static values from class */
scrNone   = .bsf~getStaticValue('java.awt.TextArea', 'SCROLLBARS_NONE')
scrVert   = .bsf~getStaticValue('java.awt.TextArea', 'SCROLLBARS_VERTICAL_ONLY')

        /* create text area objects     */
taQuery  = .awtTextArea~new('str', "", 'i',   5, 'i', 80, 'i', scrNone)
taAnswer = .awtTextArea~new('str', "" , 'i', 15, 'i', 80, 'i', scrVert)

        /* make the answer text area non-editable       */
taAnswer~setEditable("boolean", .false)

        /* create the buttons           */
butAnswer = .awtButton~new('String', ' Please answer me! ')
butLeave  = .awtButton~new('String', ' Let us stop for dooday, o.k.? ' )

        /* create gridBagLayout & constraint    */
lay    = .awtGridBagLayout~new
layCon = .awtGBConstraints~new

        /* now define details of the GridBagLayout      */
layCon~bsf.setFieldValue( 'fill',       'i', bsf('getFieldValue', layCon, 'HORIZONTAL'))
layCon~bsf.setFieldValue( 'gridwidth',  'i', bsf('getFieldValue', layCon, 'REMAINDER' ))

inset = .awtInsets~new('int', 5, 'int', 5, 'int', 5, 'int', 5)
layCon~bsf.setFieldValue( 'insets',     'o', inset)

        /* register the constraints with the layout manager     */
lay ~~setConstraints('o', label1,    'o', layCon)
lay ~~setConstraints('o', taQuery,   'o', layCon)
lay ~~setConstraints('o', butAnswer, 'o', layCon)
lay ~~setConstraints('o', label2,    'o', layCon)
lay ~~setConstraints('o', taAnswer,  'o', layCon)
lay ~~setConstraints('o', butLeave,  'o', layCon)

        /* create the frame window                              */
window = .awtFrame~new('String', 'ShootOut!')

        /* now add controls to window, change some settings of it       */
window ~~setLayout('Object', lay)
window ~~add('O', label1) ~~add('O', taQuery)  ~~add('O', butAnswer)
window ~~add('O', Label2) ~~add('O', taAnswer) ~~add('O', butLeave)

        /* pack the elements, show the window, bring it to the front    */
window ~~pack ~~show ~~toFront

        /* define the events we are interested in and the text to be sent to us */
window    ~ bsf.addEventListener('window', 'windowClosing', 'call BSF "exit"')
butAnswer ~ bsf.addEventListener('action', '', 'call answer taQuery, taAnswer, answers')
butLeave  ~ bsf.addEventListener('action', '', 'call BSF "exit"')

answers = .stream~new( "ShootAnswers.txt")~arrayin      /* read answers from file       */

do forever      /* wait and fetch the text to be sent by Java           */
   a = bsf("pollEventText")     /* wait for an eventText to be sent     */
   interpret a                  /* execute as a Rexx program    */
   if result= "SHUTDOWN, REXX !" then leave     /* JVM will be shutdown */
end
exit

::requires "BSF.cls"    -- "requires" must be the first of the directives,
                        -- this one is needed for getting access to the Object Rexx
                        -- BSF wrapper classes

        /* react to pressing the answer button  */
::routine answer
   use  arg taQuery, taAnswer, answers  /* get names of TextAreas       */
   txt=taQuery~getText                  /* get text             */

   lf = "0a"x
   txt=txt~translate("  ", "0d0a"x)~space~strip('T')
   if txt~right(1) = "?" then           /* a question in hand?          */
   do
      newLine = "0a0a"x
      tmp     =        newLine || "*** your question: ***" || newLine || txt
      tmp     = tmp || newLine || "--- my answer to you! ---" || newLine
      pick    = random(1, answers~items)/* pick a number        */
      tmp     = tmp || answers~at(pick)

      call bsf 'invoke', taAnswer, 'append',  'Str', tmp /* append to answer text area   */
      call bsf 'invoke', taQuery,  'setText', 'Str', ""
   end
   return

