/*
   Name:    "ShowSize-oo.rex"

   Invoke:  "java com.ibm.bsf.Main -lang rexx -in ShowSize-oo.rex"
                or
            "java com.ibm.bsf.Main            -in ShowSize-oo.rex"

   Purpose:  create a little resizable window with a push button to reveal the actual
             size; adds EventListeners in order for Rexx to be notified, if a button
             is pressed or the Window closed (by pressing the System close button)

   Needs:    IBM's "Bean Scripting Framework" (BSF)
             (cf. "http://oss.software.ibm.com/developerworks/projects/bsf")

             and the package "bsf4rexx"
             (cf. "http://nestroy.wi-inf.uni-essen.de/Forschung/rgf/Entwicklung.html")

   Date:    2001-04-18

   Author:   Rony G. Flatscher, University of Essen, WU Wien University,
             derived from Peter Kalender's work for the "Essener Ski Seminar",
             University of Essen (Oct 2000 to Feb 2001)
             (cf. "http://nestroy.wi-inf.uni-essen.de/Lv/seminare/ws0001/index-e.html");
*/

.bsf~import("awtFrame",  "java.awt.Frame")      -- import Java class
.bsf~import("awtButton", "java.awt.Button")     -- import Java class
.bsf~import("awtLabel",  "java.awt.Label" )     -- import Java class

window = .awtFrame~new("String", "Show Size")
window~bsf.addEventListener('window', 'windowClosing', 'call BSF "exit"')

button = .awtButton~new('String', 'Press me!')
button ~ bsf.addEventListener('action', '', 'call ShowSize window, label')

label = .awtLabel~new
label~setAlignment("I", label~bsf.getFieldValue("CENTER"))

window ~~add("string", "Center", "object", label) ~~add("St", "South", "O", button)
window  ~~pack ~~setSize("i", 250, "i", 150) ~~show ~~toFront

say "sleeping 3 seconds ..."
call syssleep 3
do i=10 to 300 by 10    -- animate the window a little bit
   call sysSleep .15
   window ~~setLocation("int", i, "int", i) ~~setSize("int", i, "int", 150) ~~show
   call showSize window, label
end
call showSize window, label

do forever
        /* using the OO-version a Java "null" string will
           translated automatically into the Object Rexx
           equivalent, i.e. .nil        */
   a = .bsf~pollEventText(1000) /* wait for an eventText to be sent,
                                   after 1 second return anyway */
   if a=.nil then say "Rexx: no eventText so far ..."
   else
   do
      say "received the following eventText: ["a"]"
      interpret a               /* execute as a Rexx program    */
      if result= "SHUTDOWN, REXX !" then leave     /* JVM will be shutdown      */
      say "Rexx: sleeping 3 secs"
      call syssleep 3
      say "Rexx: awakened!"
   end
end

exit


ShowSize: procedure
   use arg window, label                        /* get proxy objects    */

   parse value (window~getSize~toString) with "width=" width ",height=" height "]"
   label~setText("String", width "/" height )
   return

::requires "BSF.cls"    -- include direct Object Rexx BSF support

