/*
   Name:    "ShowSize.rex"

   Invoke:  "java com.ibm.bsf.Main -lang rexx -in ShowSize.rex"
                or
            "java com.ibm.bsf.Main            -in ShowSize.rex"

   Purpose:  create a little resizable window with a push button to reveal the actual
             size; adds EventListeners in order for Rexx to be notified, if a button
             is pressed or the Window closed (by pressing the System close button)

   Needs:    IBM's "Bean Scripting Framework" (BSF)
             (cf. "http://oss.software.ibm.com/developerworks/projects/bsf")

             and the package "bsf4rexx"
             (cf. "http://nestroy.wi-inf.uni-essen.de/Forschung/rgf/Entwicklung.html")

   Date:    2001-04-18

   Author:   Rony G. Flatscher, University of Essen, WU Wien University,
             derived from Peter Kalender's work for the "Essener Ski Seminar",
             University of Essen (Oct 2000 to Feb 2001)
             (cf. "http://nestroy.wi-inf.uni-essen.de/Lv/seminare/ws0001/index-e.html");
*/

call BSF 'registerBean', 'Window', 'java.awt.Frame', 'String', 'Show size'
call BSF 'addEventListener', 'Window', 'window', 'windowClosing', 'call BSF "exit"'

call BSF 'registerBean', 'Button', 'java.awt.Button', 'String', 'Press me!'
call BSF 'addEventListener', 'Button', 'action', '', 'call ShowSize'

call BSF 'registerBean', 'Label', 'java.awt.Label'
call BSF 'invoke', 'Label', 'setAlignment', 'I', bsf('getFieldValue', 'Label', 'CENTER')

call BSF 'invoke', 'Window', 'add', 'String', 'Center', 'Object',  'Label'
call BSF 'invoke', 'Window', 'add', 'String', 'South',   'Object', 'Button'
call BSF 'invoke', 'Window', 'pack'
call BSF 'invoke', 'Window', 'setSize', 'int', 250, 'int', 150
call BSF 'invoke', 'Window', 'show'
call BSF 'invoke', 'Window', 'toFront'

say "sleeping 3 seconds ..."
call syssleep 3
do i=10 to 300 by 10    -- animate the window a little bit
   call sysSleep .1
   call BSF 'invoke', 'Window', 'setLocation', 'int', i, 'int', i
   call BSF 'invoke', 'Window', 'setSize', 'int', i, 'int', 150
   call BSF 'invoke', 'Window', 'show'
   call ShowSize
end
call showSize


do forever
        /* a direct call always returns a string, in the
           case of a Java "null" by default the string ".NIL"   */
   a = bsf("pollEventText", 1000)       /* wait for an eventText to be sent,
                                           after 1 second return anyway         */

   if a=".NIL" then say "Rexx: no eventText so far ..."
   else
   do
      say "received the following eventText: ["a"]"
      interpret a                  /* execute as a Rexx program    */
      if result= "SHUTDOWN, REXX !" then leave     /* JVM will be shutdown in 1/10sec      */
      say "Rexx: sleeping 3 secs"
      call syssleep 3
      say "Rexx: awakened!"
   end
end
exit


ShowSize: procedure

   dim   =bsf('invoke', 'Window', 'getSize')    /* get dimension object */
   string=bsf('invoke', dim, 'toString')        /* get String rendering */
   call BSF 'unregisterBean', dim               /* free Java registry   */

   parse var string "width=" width ",height=" height "]"
   call BSF 'invoke', 'Label', 'setText', 'String', "(" width "/" height ")"
   return




